@@ -7,15 +7,13 @@ package Comics::Plugin::Glasbergen;
 
 use parent qw(Comics::Fetcher::Single);
 
-our $VERSION = "1.01";
+our $VERSION = "1.03";
 
 our $name    = "Glasbergen";
 our $url     = "http://www.glasbergen.com";
 our $pattern =
-	    qr{ <img \s+ class="ngg-singlepic" \s+
-		(?: title="(?<title>.*?)" \s+ )?
-		(?: alt="(?<alt>.*?)" \s+ )?
-		src="(?<url>http://www.glasbergen.com/wp-content/
+	    qr{ <div \s+ class="ngg-widget \s+ entry-content" \s* > \s*
+		<a \s+ href="(?<url>https?://www.glasbergen.com/wp-content/
 		gallery/cartoons/(?<image>.+?))" \s*
 	      }x;
 
